This function creates a MA plot to visualize differential expression results. It shows the relationship between mean expression and log2 fold change for each gene.
Usage
plot_ma(res, fc.thresh = 0.5, save_plot = TRUE, save_dir = getwd())This function creates a MA plot to visualize differential expression results. It shows the relationship between mean expression and log2 fold change for each gene.
plot_ma(res, fc.thresh = 0.5, save_plot = TRUE, save_dir = getwd())