Skip to contents

This function runs the differential expression analysis and generates MA and volcano plots for a single comparison

Usage

run_diffexp_pip(
  dds,
  org,
  group_by,
  order = "pxfc",
  one_to_all = FALSE,
  save_dir = getwd()
)

Arguments

dds

DESeq2 object containing the expression data

org

The organism to use, either "human" or "mouse".

group_by

Column name in colData(dds) to use for grouping.

order

Column name to use for ranking genes. Default is "pxfc"

one_to_all

Logical. If TRUE, runs one-to-all comparisons. Default is FALSE

save_dir

Directory where all output files will be saved. Default is current working directory

Value

A data frame containing differential expression results for a comparison

Examples

if (FALSE) { # \dontrun{
# Run differential expression pipeline
res <- run_diffexp_pip(dds, group_by = "group", one_to_all = T, save_dir = "results")
} # }