Skip to contents

This function saves expression data from a DESeq2 object in various formats, including the DESeq2 object itself, raw counts, normalized expression values, and class labels for GSEA.

Usage

save_expression(dds, group_by, save_dir = getwd())

Arguments

dds

DESeq2 object containing the expression data

save_dir

Directory to save files. Default is the current working directory

save_dir_name

Name of the subdirectory to save files in. Default is "qc_results"

Value

Nothing, but saves the following files: - DESeq2 object as RDS - Raw counts as TSV - Variance-stabilized transformed data as TSV - CLS file with class labels

Examples

if (FALSE) { # \dontrun{
# Save expression data with default settings
save_expression(dds)

# Save expression data with custom grouping and directory name
save_expression(dds, group_by = "Treatment", save_dir_name = "custom_results")
} # }